Crate serum_swap

Crate serum_swap 

Program to perform instantly settled token swaps on the Serum DEX.

Before using any instruction here, a user must first create an open orders account on all markets being used. This only needs to be done once, either via the system program create account instruction in the same transaction as the user’s first trade or via the explicit init_account and close_account instructions provided here, which can be included in transactions.

Re-exports

pub extern crate karima_anchor_lang as anchor_lang;
pub extern crate karima_anchor_spl as anchor_spl;

Modules

accounts
An Anchor generated module, providing a set of structs mirroring the structs deriving Accounts, where each field is a Pubkey. This is useful for specifying accounts for a client.
instruction
An Anchor generated module containing the program’s set of instructions, where each method handler in the #[program] mod is associated with a struct defining the input arguments to the method. These should be used directly, when one wants to serialize Anchor instruction data, for example, when speciying instructions on a client.
program
serum_swap

Structs

CloseAccount
DidSwap
ExchangeRate
InitAccount
MarketAccounts
Swap
SwapTransitive

Enums

ErrorCode
Side

Constants

ID
The const program ID.

Functions

check_id
Returns true if given pubkey is the program ID.
entry
The Anchor codegen exposes a programming model where a user defines a set of methods inside of a #[program] module in a way similar to writing RPC request handlers. The macro then generates a bunch of code wrapping these user defined methods into something that can be executed on Solana.
entrypoint
Safety
id
Returns the program ID.

Type Aliases

Result
Anchor generated Result to be used as the return type for the program.